<?php
/**
 * AMQPInstance Class
 *
 * This is simply a wrapper around a connection, channel and exchange
 * to make interacting with the AMQP server easier. 
 */
class AMQPInstance {
  
  private $connection;
  private $channel;
  private $exchange;
  private $exchangeName;
  private $queue;

  private function initialize_queue($queueName = '', $routingKey = '') {
    /* create a queue object */
    $this->queue = new AMQPQueue($this->channel);
    $this->queue->setName($queueName);
    
    //declare (and bind) the queue
    $this->queue->declare();
    $this->queue->bind($this->exchangeName, $routingKey);
  }

  function __destruct() {
    $this->connection->disconnect();
  }

  function connect($conn_args) {
    $this->connection = new AMQPConnection($conn_args);
    $this->connection->connect();
    return $this;
  }

  function channel() {
    $this->channel = new AMQPChannel($this->connection);
    return $this;
  }

  function exchange($exchangeName, $params = array()) {
    $this->exchangeName = $exchangeName;

    $this->exchange = new AMQPExchange($this->channel);
    $this->exchange->setName($this->exchangeName);

    if (array_key_exists('type', $params)) {
      $this->exchange->setType($params['type']);
    }
    if (array_key_exists('flags', $params)) {
      $this->exchange->setFlags($params['flags']);
    }
    $this->exchange->declare();
    return $this;
  }

  function publish($message, $routingKey) {
    $this->exchange->publish($message, $routingKey);
  }

  function consume($queueName = '', $routingKey = '') {
    $this->initialize_queue($queueName, $routingKey);

    //get the message
    if ($message = $this->queue->get(AMQP_AUTOACK)) {
      return $message->getBody();
    } 
    return $message;
  }

  /**
   * Do we even need this?  Thought it'd be helpful for debugging, but otherwise kind of defeats
   * the purpose of a "Message Queue" server handling the messages.
   */
  // protected function consume_all($queueName = '', $routingKey = '') {

  //  $this->initialize_queue($queueName, $routingKey);

  //  //get the message
  //  $messages = array();
  //  $message = $queue->get(AMQP_AUTOACK);

  //  while($message) {
  //    $msgBody = $message->getBody();
  //    $messages[$this->exchangeName][$routingKey][] = $msgBody;   
  //    sleep(1);
  //    $message = $queue->get(AMQP_AUTOACK);
  //  }
  //  return $messages;

  // }

}
